import COM.hugin.GUI.*;
import COM.hugin.HAPI.*;

import javax.swing.*;
import java.awt.event.*;
import java.awt.Color;

public class TestCanvas {
    public static void main(String[] args) {
	switch (args.length) {
	case 1:
	    testCanvas(args[0]);
	    return;
	default:
	    System.err.println("Usage:");
	    System.err.println("          java TestCanvas <path-to-net-file->");
	    System.exit(1);
	}
    }


    private static void testCanvas(final String netFile) {
	try {
	    //the driver breathes life into our GUI elements - responds to user events and updates HUGIN objects and GUI elements accordingly
	    final Driver driver = new Driver();
	    
	    //load and compile a domain (domain must be compiled in order to perform inference)
	    final Domain domain = new Domain(netFile, new DefaultClassParseListener());
	    domain.compile();

	    HuginCanvas canvas = driver.inflateNetwork(new HuginCanvas(), domain);

	    //iterate all widgets
	    for (Base widget : driver.getWidgets()) {
		if (widget instanceof DiscreteMonitor)
		    System.out.println(((DiscreteMonitor)widget).getHuginName());
	    }

	    //register our own UserEvent handler so we can pick up when user has interacted with domain
	    driver.setUserEventHandler(new UserEventHandler() {
		    public void handleUserEvent(UserEvent userEvent) {
			System.out.println("userEvent");
			if (userEvent instanceof UserEvent.ClickedWidget) {
			    UserEvent.ClickedWidget ue = (UserEvent.ClickedWidget)userEvent;
			    System.out.println("Clicked widget " + ue.name);
			    if (ue.targetWidget.getHuginBackgroundColor() == Color.white)
				ue.targetWidget.setHuginBackgroundColor(Color.lightGray);
			    else
				ue.targetWidget.setHuginBackgroundColor(Color.white);
			}
		    }
		});
	    	    
	    //create a jframe and display our panel of GUI elements
	    JFrame frame = new JFrame("HuginCanvas Test");
	    frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

	    //add the HUGIN Canvas directly to the JFrame
	    frame.add(canvas);
	    frame.setSize(350, 400);
	    frame.addWindowListener(new WindowAdapter() {
		    public void windowClosing(WindowEvent e) {
			//clean-up HUGIN objects
			try {
			    domain.delete();
			} catch (ExceptionHugin eh) {
			    eh.printStackTrace();
			}
		    }
		});
	    frame.setVisible(true);
	} catch (Exception ex) {
	    ex.printStackTrace();
	}
    }




}


